==> woocommerce-rtm-custom-emails.0.0.8.zip: src/Preview/ObjectSupport/EmailUserSupport.php <==
<?php

namespace RTMCustomMails\Preview\ObjectSupport;

class EmailUserSupport extends EmailObjectSupport
{

    public function __construct()
    {
        parent::__construct('user');
    }

    protected function getSelectorConfig(): array
    {
        return [
            'valueField' => 'id',
            'textField' => 'name',
            'searchField' => [
                [
                    'field' => 'name',
                    'weight' => 2
                ],
                [
                    'field' => 'email',
                    'weight' => 1.5
                ],
                [
                    'field' => 'id',
                    'weight' => 0.5
                ]
            ],
            'render' => [
                'option' => '<div>{id}: {name} ({email})</div>',
                'item' => '<div>{id}: {name} ({email})</div>',
            ]
        ];
    }

    public function getAllowedContextVariables($vars = []): array
    {
        return $vars;
    }

    public function findObjects(array $objects, string $search): array
    {
        $query = new \WP_User_Query([
            'search' => '*' . esc_attr($search) . '*',
            'search_columns' => [
                'user_login',
                'user_nicename',
                'user_email',
            ],
            'number' => 20,
            'orderby' => 'ID',
            'order' => 'DESC'
        ]);
        $users = $query->get_results();
        return array_merge($objects, array_map([$this, 'simplifyUser'], $users));
    }

    public function simplifyUser(\WP_User $user)
    {
        return [
            'id' => $user->ID,
            'name' => $user->display_name,
            'email' => $user->user_email
        ];
    }

    public function getLatestObjects(int $amount = 20): array
    {
        $users = get_users([
            'role__not_in' => ['administrator'],
            'number' => $amount,
            'orderby' => 'ID',
            'order' => 'DESC'
        ]);
        return array_map([$this, 'simplifyUser'], $users);
    }

    public function addTriggerHookOptions(array $options = []): array
    {
        return $options + [
                'woocommerce_reset_password_notification' => 'User password was reset.'
            ];
    }
}

==> woocommerce-rtm-custom-emails.0.1.1.zip: src/Preview/ObjectSupport/EmailUserSupport.php <==
<?php

namespace RTMCustomMails\Preview\ObjectSupport;

use WP_User;
use WP_User_Query;

class EmailUserSupport extends EmailObjectSupport
{

    public function __construct()
    {
        parent::__construct('user');
    }

    protected function getSelectorConfig(): array
    {
        return [
            'valueField' => 'id',
            'textField' => 'name',
            'searchField' => [
                [
                    'field' => 'name',
                    'weight' => 2
                ],
                [
                    'field' => 'email',
                    'weight' => 1.5
                ],
                [
                    'field' => 'id',
                    'weight' => 0.5
                ]
            ],
            'render' => [
                'option' => '<div>{id}: {name} ({email})</div>',
                'item' => '<div>{id}: {name} ({email})</div>',
            ]
        ];
    }

    public function getAllowedContextVariables($vars = []): array
    {
        return $vars;
    }

    public function findObjects(array $objects, string $search): array
    {
        $query = new WP_User_Query([
            'search' => '*' . esc_attr($search) . '*',
            'search_columns' => [
                'user_login',
                'user_nicename',
                'user_email',
            ],
            'number' => 20,
            'orderby' => 'ID',
            'order' => 'DESC'
        ]);
        $users = $query->get_results();
        return array_merge($objects, array_map([$this, 'simplifyUser'], $users));
    }

    public function simplifyUser(WP_User $user): array
    {
        return [
            'id' => $user->ID,
            'name' => $user->display_name,
            'email' => $user->user_email
        ];
    }

    public function getLatestObjects(int $amount = 20): array
    {
        $users = get_users([
            'role__not_in' => ['administrator'],
            'number' => $amount,
            'orderby' => 'ID',
            'order' => 'DESC'
        ]);
        return array_map([$this, 'simplifyUser'], $users);
    }

    public function addTriggerHookOptions(array $options = []): array
    {
        return $options + [
                'woocommerce_reset_password_notification' => 'User password was reset.'
            ];
    }
}
